# CHANGELOG.md

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.2.0

### Added

- supports now lazy loading for large datasets

### Changed

- the order of dimensions is now "sample", "wavelength", "point"

## 0.1.1

### Fixed

- unwanted warnings when black and white are present

## 0.1.0

### Added

- added changelog
- added bump-my-version

